@@ -1,9 +1,7 @@
-import sys
 import unittest
 
 
 class CacheTestMixin:
-
     Cache = None
 
     def test_defaults(self):
@@ -100,15 +98,17 @@ class CacheTestMixin:
         cache = self.Cache(maxsize=2)
 
         cache.update({1: 1, 2: 2})
-        self.assertIn(cache.pop(1), {1: 1, 2: 2})
+
+        key, _ = cache.popitem()
+        self.assertIn(key, {1, 2})
         self.assertEqual(1, len(cache))
-        self.assertIn(cache.pop(2), {1: 1, 2: 2})
+        key, _ = cache.popitem()
+        self.assertIn(key, {1, 2})
         self.assertEqual(0, len(cache))
 
         with self.assertRaises(KeyError):
             cache.popitem()
 
-    @unittest.skipUnless(sys.version_info >= (3, 7), "requires Python 3.7")
     def test_popitem_exception_context(self):
         # since Python 3.7, MutableMapping.popitem() suppresses
         # exception context as implementation detail
@@ -302,3 +302,31 @@ class CacheTestMixin:
             cache = pickle.loads(pickle.dumps(source))
             self.assertEqual(n, len(cache))
             self.assertEqual(source, cache)
+
+
+class CountedLock:
+    def __init__(self):
+        self.count = 0
+
+    def __enter__(self):
+        self.count += 1
+
+    def __exit__(self, *exc):
+        pass
+
+
+class CountedCondition(CountedLock):
+    def __init__(self):
+        super().__init__()
+        self.wait_count = 0
+        self.notify_count = 0
+
+    # only wait_for() and notify_all() are used in the cache tests,
+    # calling wait() or notify() will fail intentionally
+
+    def wait_for(self, predicate):
+        assert callable(predicate)
+        self.wait_count += 1
+
+    def notify_all(self):
+        self.notify_count += 1
